======
Author
======

tt is written by Brian Welch. If you'd like to discuss anything about this library, Python, or software engineering in general, please feel free to reach out via one of the below channels.

    * `Personal website`_
    * `Github`_


.. _Personal website: https://brianwel.ch/
.. _Github: https://github.com/welchbj/
